@@ -317,9 +317,9 @@ add_y_date_gst_tag (TrackerSparqlBuilder  *metadata,
 	}
 
 	tracker_guarantee_date_from_file_mtime (metadata,
-	                                            key,
-	                                            buf,
-	                                            uri);
+	                                        key,
+	                                        buf,
+	                                        uri);
 }
 
 static void
@@ -508,8 +508,6 @@ extract_metadata (MetadataExtractor      *extractor,
 	const gchar *temp;
 	gchar *make = NULL, *model = NULL, *manuf = NULL;
 	gchar *composer = NULL, *albumname = NULL, *genre = NULL;
-	gboolean ret;
-	gint count;
 	gboolean needs_audio = FALSE;
 
 	g_return_if_fail (extractor != NULL);
@@ -529,6 +527,10 @@ extract_metadata (MetadataExtractor      *extractor,
 			gst_tag_list_get_string (extractor->tagcache, GST_TAG_VIDEO_CODEC, &video_codec);
 			gst_tag_list_get_string (extractor->tagcache, GST_TAG_AUDIO_CODEC, &audio_codec);
 
+			g_debug ("Reading codecs from the stream... audio: '%s', video: '%s'",
+			         audio_codec ? audio_codec : "none",
+			         video_codec ? video_codec : "none");
+
 			if (audio_codec && !video_codec) {
 				extractor->mime = EXTRACT_MIME_AUDIO;
 			} else {
@@ -778,9 +780,9 @@ extract_metadata (MetadataExtractor      *extractor,
 		s = NULL;
 		gst_tag_list_get_string (extractor->tagcache, GST_TAG_TITLE, &s);
 		tracker_guarantee_title_from_file (metadata,
-		                                       "nie:title",
-		                                       s,
-		                                       uri);
+		                                   "nie:title",
+		                                   s,
+		                                   uri);
 		g_free (s);
 
 		add_string_gst_tag (metadata, uri, "nie:copyright", extractor->tagcache, GST_TAG_COPYRIGHT);
@@ -846,9 +848,10 @@ extract_metadata (MetadataExtractor      *extractor,
 		}
 
 		if (needs_audio) {
+			guint count;
+
 			/* Audio */
-			ret = gst_tag_list_get_uint (extractor->tagcache, GST_TAG_TRACK_COUNT, &count);
-			if (ret) {
+			if (gst_tag_list_get_uint (extractor->tagcache, GST_TAG_TRACK_COUNT, &count)) {
 				*scount = g_strdup_printf ("%d", count);
 			}
 
@@ -884,11 +887,12 @@ extract_metadata (MetadataExtractor      *extractor,
 		g_free (album_disc_uri);
 
 		add_string_gst_tag (metadata, uri, "nfo:codec", extractor->tagcache, GST_TAG_AUDIO_CODEC);
+	} else if (extractor->mime == EXTRACT_MIME_GUESS) {
+		g_warning ("Cannot guess real stream type if no tags were read! "
+		           "Defaulting to Video.");
+		tracker_sparql_builder_predicate (metadata, "a");
+		tracker_sparql_builder_object (metadata, "nmm:Video");
 	} else {
-		if (extractor->mime == EXTRACT_MIME_GUESS) {
-			g_warning ("Cannot guess real stream type if no tags were read!");
-		}
-
 		if (extractor->mime == EXTRACT_MIME_AUDIO)
 			needs_audio = TRUE;
 
@@ -912,6 +916,11 @@ extract_metadata (MetadataExtractor      *extractor,
 		}
 	}
 
+	/* If content was encrypted, set it. */
+	if (extractor->is_content_encrypted) {
+		tracker_sparql_builder_predicate (metadata, "nfo:isContentEncrypted");
+		tracker_sparql_builder_object_boolean (metadata, TRUE);
+	}
 
 	if (use_tagreadbin) {
 		extract_stream_metadata_tagreadbin (extractor, uri, metadata);
@@ -1111,6 +1120,9 @@ poll_for_ready (MetadataExtractor *extractor,
 
 					g_free (error_debug_message);
 					g_error_free (lerror);
+
+					/* We really need to keep on reading as tags may come
+					 * afterwards, like codec tags in DRM-ed files. */
 					break;
 				}
 			}
@@ -1188,9 +1200,9 @@ create_decodebin_pipeline (MetadataExtractor *extractor,
 	}
 
 	g_signal_connect (G_OBJECT (bin),
-			  "new-decoded-pad",
-			  G_CALLBACK (dbin_dpad_cb),
-			  extractor);
+	                  "new-decoded-pad",
+	                  G_CALLBACK (dbin_dpad_cb),
+	                  extractor);
 
 	gst_bin_add (GST_BIN (pipeline), filesrc);
 	gst_bin_add (GST_BIN (pipeline), bin);
@@ -1297,7 +1309,7 @@ tracker_extract_gstreamer (const gchar *uri,
 			return;
 		}
 
-		add_stream_tags(extractor);
+		add_stream_tags (extractor);
 		gst_element_set_state (extractor->pipeline, GST_STATE_READY);
 		gst_element_get_state (extractor->pipeline, NULL, NULL, 5 * GST_SECOND);
 		g_list_foreach (extractor->fsinks, unlink_fsink, extractor);
@@ -1369,7 +1381,7 @@ extract_gstreamer_svg (const gchar          *uri,
 
 static void
 extract_gstreamer_guess (const gchar          *uri,
-                        TrackerSparqlBuilder *preupdate,
+                         TrackerSparqlBuilder *preupdate,
                          TrackerSparqlBuilder *metadata)
 {
 	tracker_extract_gstreamer (uri, preupdate, metadata, EXTRACT_MIME_GUESS);
